@@ -43,6 +43,10 @@
 #ifndef	CCXX_ADDRESS_H_
 #define	CCXX_ADDRESS_H_
 
+#ifndef CCXX_CONFIG_H_
+#include <cc++/config.h>
+#endif
+
 #ifndef	CCXX_MISSING_H_
 #include <cc++/missing.h>
 #endif
@@ -55,11 +59,6 @@
 #include <cc++/exception.h>
 #endif
 
-#if defined(WIN32) && !defined(__CYGWIN32__)
-#define	__WINSOCK__
-#include <winsock2.h>
-#endif
-
 #ifdef	CCXX_NAMESPACES
 namespace ost {
 #endif
