@@ -589,7 +589,7 @@ public:
  * @short This class is very anagolous to TCPSession.
  */
 
-class TTYSession : public TTYStream, public Thread
+class __EXPORT TTYSession : public Thread, public TTYStream
 {
 public:
 	/**
@@ -600,6 +600,8 @@ public:
 	 * @param stack allocation needed on some platforms.
 	 */
 	TTYSession(const char *name, int pri = 0, int stack = 0);
+
+	virtual ~TTYSession();
 };
 
 #ifndef	WIN32
