@@ -875,7 +875,7 @@ public:
 class __EXPORT UDPBroadcast : public UDPSocket
 {
 private:
-	void setPeer(const IPV4Host &ia, tpport_t port) {};
+	void setPeer(const IPV4Host &ia, tpport_t port);
 
 	Error setBroadcast(bool enable)
 		{return Socket::setBroadcast(enable);};
@@ -1787,8 +1787,7 @@ class __EXPORT SimpleTCPStream : public Socket
 {
 private:
 
-	inline IPV4Host getSender(tpport_t *port) const
-		{ return IPV4Host(); };
+	IPV4Host getSender(tpport_t *port) const;
 
 protected:
 	/**
