@@ -86,6 +86,10 @@ typedef DWORD   timeout_t;
 
 #endif // !WIN32
 
+#ifdef  HAVE_GCC_CXX_BITS_ATOMIC
+#include <ios>
+#endif
+
 #ifdef	CCXX_NAMESPACES
 namespace ost {
 #ifdef __BORLANDC__
