@@ -58,9 +58,6 @@
 #ifdef	HAVE_NET_IF_H
 #include <net/if.h>
 #endif
-#else
-#include <winsock2.h>
-#include <ws2tcpip.h>
 #endif
 
 #ifdef	CCXX_NAMESPACES
@@ -68,7 +65,7 @@ namespace ost {
 #endif
 
 #if defined(HAVE_NET_IF_H) || defined(WIN32)
-#if !defined(_MSC_VER) || _MSC_VER >= 1300 || defined(HAVE_PLATFORMSDK)
+#if !defined(_MSC_VER) || _MSC_VER >= 1300
 
 using namespace std;
 
