@@ -128,11 +128,11 @@ bool Socket::check(Family fam)
 	switch(fam)
 	{
 	case IPV4:
-		so = socket(fam, SOCK_DGRAM, 0);
+		so = socket(fam, SOCK_DGRAM, IPPROTO_UDP);
 		break;
 #ifdef	CCXX_IPV6
 	case IPV6:
-		so = socket(fam, SOCK_DGRAM, 0);
+		so = socket(fam, SOCK_DGRAM, IPPROTO_UDP);
 		break;
 #endif
 	}
@@ -1280,7 +1280,7 @@ Socket::Error Socket::drop(const IPV6Multicast &ia)
 #ifdef	HAVE_GETADDRINFO
 
 UDPSocket::UDPSocket(const char *name, Family fam) :
-Socket(fam, SOCK_DGRAM, 0)
+Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 {
 	char namebuf[128], *cp;
 	struct addrinfo hint, *list = NULL, *first;
@@ -1360,7 +1360,7 @@ Socket(fam, SOCK_DGRAM, 0)
 #else
 
 UDPSocket::UDPSocket(const char *name, Family fam) :
-Socket(fam, SOCK_DGRAM, 0)
+Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 {
 	char namebuf[128], *cp;
 	tpport_t port;
@@ -1453,7 +1453,7 @@ Socket(fam, SOCK_DGRAM, 0)
 #endif
 
 UDPSocket::UDPSocket(Family fam) :
-Socket(fam, SOCK_DGRAM, 0)
+Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 {
 	family = fam;
 	memset(&peer, 0, sizeof(peer));
@@ -1470,7 +1470,7 @@ Socket(fam, SOCK_DGRAM, 0)
 }
 
 UDPSocket::UDPSocket(const IPV4Address &ia, tpport_t port) :
-Socket(AF_INET, SOCK_DGRAM, 0)
+Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 {
 	family = IPV4;
 	memset(&peer.ipv4, 0, sizeof(peer));
@@ -1492,7 +1492,7 @@ Socket(AF_INET, SOCK_DGRAM, 0)
 
 #ifdef  CCXX_IPV6
 UDPSocket::UDPSocket(const IPV6Address &ia, tpport_t port) :
-Socket(AF_INET6, SOCK_DGRAM, 0)
+Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 {
 	family = IPV6;
 	memset(&peer.ipv6, 0, sizeof(peer));
@@ -1957,7 +1957,7 @@ void TCPSocket::setSegmentSize(unsigned mss)
 
 #ifdef	HAVE_GETADDRINFO
 TCPSocket::TCPSocket(const char *name, unsigned backlog, unsigned mss) :
-Socket(AF_INET, SOCK_STREAM, 0)
+Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 {
 	char namebuf[128], *cp;
 	struct addrinfo hint, *list = NULL, *first;
@@ -2027,7 +2027,7 @@ Socket(AF_INET, SOCK_STREAM, 0)
 
 #else
 TCPSocket::TCPSocket(const char *name, unsigned backlog, unsigned mss) :
-Socket(AF_INET, SOCK_STREAM, 0)
+Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 {
 	char namebuf[128], *cp;
         struct sockaddr_in addr;
@@ -2099,7 +2099,7 @@ Socket(AF_INET, SOCK_STREAM, 0)
 #endif	
 
 TCPSocket::TCPSocket(const IPV4Address &ia, tpport_t port, unsigned backlog, unsigned mss) :
-Socket(AF_INET, SOCK_STREAM, 0)
+Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 {
 	struct sockaddr_in addr;
 
@@ -2154,7 +2154,7 @@ void TCPV6Socket::setSegmentSize(unsigned mss)
 
 #ifdef	HAVE_GETADDRINFO
 TCPV6Socket::TCPV6Socket(const char *name, unsigned backlog, unsigned mss) :
-Socket(AF_INET6, SOCK_STREAM, 0)
+Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 {
 	char namebuf[128], *cp;
 	struct addrinfo hint, *list = NULL, *first;
@@ -2224,7 +2224,7 @@ Socket(AF_INET6, SOCK_STREAM, 0)
 
 #else
 TCPV6Socket::TCPV6Socket(const char *name, unsigned backlog, unsigned mss) :
-Socket(AF_INET6, SOCK_STREAM, 0)
+Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 {
 	char namebuf[128], *cp;
         struct sockaddr_in6 addr;
@@ -2295,7 +2295,7 @@ Socket(AF_INET6, SOCK_STREAM, 0)
 #endif	
 
 TCPV6Socket::TCPV6Socket(const IPV6Address &ia, tpport_t port, unsigned backlog, unsigned mss) :
-Socket(AF_INET6, SOCK_STREAM, 0)
+Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 {
 	struct sockaddr_in6 addr;
 
@@ -2432,7 +2432,7 @@ TCPStream::TCPStream(TCPV6Socket &server, bool throwflag, timeout_t to) :
 #endif
 
 TCPStream::TCPStream(const IPV4Host &host, tpport_t port, unsigned size, bool throwflag, timeout_t to) :
-	streambuf(), Socket(AF_INET, SOCK_STREAM, 0),
+	streambuf(), Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP),
 #ifdef	HAVE_OLD_IOSTREAM
 	iostream(),
 #else
@@ -2451,7 +2451,7 @@ TCPStream::TCPStream(const IPV4Host &host, tpport_t port, unsigned size, bool th
 
 #ifdef  CCXX_IPV6
 TCPStream::TCPStream(const IPV6Host &host, tpport_t port, unsigned size, bool throwflag, timeout_t to) :
-	streambuf(), Socket(AF_INET6, SOCK_STREAM, 0),
+	streambuf(), Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP),
 #ifdef	HAVE_OLD_IOSTREAM
 	iostream(),
 #else
@@ -2666,7 +2666,7 @@ void TCPStream::connect(const IPV4Host &host, tpport_t port, unsigned mss)
 				break;
 			}
 			endSocket();
-			so = socket(AF_INET, SOCK_STREAM, 0);
+			so = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
 			if(so == INVALID_SOCKET)
 				break;
 		}
@@ -2747,7 +2747,7 @@ void TCPStream::connect(const IPV6Host &host, tpport_t port, unsigned mss)
 				break;
 			}
 			endSocket();
-			so = socket(AF_INET6, SOCK_STREAM, 0);
+			so = socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP);
 			if(so == INVALID_SOCKET)
 				break;
 		}
@@ -2769,7 +2769,7 @@ void TCPStream::connect(const IPV6Host &host, tpport_t port, unsigned mss)
 #endif
 
 TCPStream::TCPStream(const char *target, Family fam, unsigned mss, bool throwflag, timeout_t to) :
-        streambuf(), Socket(PF_INET, SOCK_STREAM, 0),
+        streambuf(), Socket(PF_INET, SOCK_STREAM, IPPROTO_TCP),
 #ifdef  HAVE_OLD_IOSTREAM
         iostream(),
 #else
@@ -2787,7 +2787,7 @@ TCPStream::TCPStream(const char *target, Family fam, unsigned mss, bool throwfla
 }
 
 TCPStream::TCPStream(Family fam, bool throwflag, timeout_t to) :
-	streambuf(), Socket(PF_INET, SOCK_STREAM, 0),
+	streambuf(), Socket(PF_INET, SOCK_STREAM, IPPROTO_TCP),
 #ifdef	HAVE_OLD_IOSTREAM
 	iostream(),
 #else
@@ -2936,7 +2936,7 @@ void TCPStream::disconnect(void)
 		return;
 
 	endStream();
-	so = socket(family, SOCK_STREAM, 0);
+	so = socket(family, SOCK_STREAM, IPPROTO_TCP);
 	if(so != INVALID_SOCKET)
 		Socket::state = AVAILABLE;
 }
