@@ -485,7 +485,7 @@ void URLStream::close(void)
 		return;
 
 	endStream();
-	so = socket(AF_INET, SOCK_STREAM, 0);
+	so = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
 	if(so != INVALID_SOCKET)
 		Socket::state = AVAILABLE;
 }
