@@ -78,43 +78,72 @@
 * @todo Why may be need using kernel object Mutex as a background for ost::Mutex?
 */
 
-/**
- * Determine if platform SDK is installed.  Comment this line out
- * if using VS6 without any Platform SDK updates...
- */
-#define	HAVE_PLATFORMSDK
-
-/**
- * Some sanity checks for platformsdk support based on build env.
- */
-
-#ifndef	HAVE_PLATFORMSDK
-#if defined(_MSC_VER) && _MSC_VER >= 1300
-#define	HAVE_PLATFORMSDK
-#else
-#if defined(__MINGW32__) || defined(__CYGWIN32__)
-#undef	HAVE_PLATFORMSDK
-#endif
-#endif
-#endif
-
 // Select the way, that the ost::Mutex based on.
 //#define MUTEX_UNDERGROUND_WIN32_MUTEX
 #define MUTEX_UNDERGROUND_WIN32_CRITICALSECTION
 
-// Require for compiling with critical sections.  
-#define _WIN32_WINNT 0x0400
+/*
+http://msdn.microsoft.com/library/en-us/winprog/winprog/using_the_windows_headers.asp
 
-#if	!defined(HAVE_PLATFORMSDK)
-#include <windows.h>
+Minimum system required    Macros to define 
+
+Windows "Longhorn"         _WIN32_WINNT >= 0x0600
+                           WINVER >= 0x0600
+ 
+Windows Server 2003        _WIN32_WINNT> = 0x0502
+                           WINVER >= 0x0502
+ 
+Windows XP                 _WIN32_WINNT >= 0x0501
+                           WINVER >= 0x0501
+ 
+Windows 2000               _WIN32_WINNT >= 0x0500
+                           WINVER >= 0x0500
+ 
+Windows NT 4.0             _WIN32_WINNT >= 0x0400
+                           WINVER >= 0x0400
+ 
+Windows Me                 _WIN32_WINDOWS >= 0x0500
+                           WINVER >= 0x0500
+ 
+Windows 98                 _WIN32_WINDOWS >= 0x0410
+                           WINVER >= 0x0410
+ 
+Windows 95                 _WIN32_WINDOWS >= 0x0400
+                           WINVER >= 0x0400
+
+Faster Builds with Smaller Header Files
+
+WIN32_LEAN_AND_MEAN
+*/
+ 
+// Require for compiling with critical sections.
+#ifndef _WIN32_WINNT
+#define _WIN32_WINNT 0x0400
 #endif
+
+// Make sure we're consistent with _WIN32_WINNT
+#ifndef WINVER
+#define WINVER _WIN32_WINNT
+#endif
+
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN
+#define _CCXX_WIN32_LEAN_AND_MEAN_
+#endif
+
 #include <winsock2.h>
 #include <ws2tcpip.h>
-#if defined(HAVE_PLATFORMSDK)
-#include <windows.h>
+
+#ifdef _CCXX_WIN32_LEAN_AND_MEAN_
+#undef WIN32_LEAN_AND_MEAN
+#undef _CCXX_WIN32_LEAN_AND_MEAN_
+#endif
+
+#if _WIN32_WINNT >= 0x0501
 #define CCXX_IPV6
 #endif
-#endif
+
+#endif /* #ifndef CCXX_WIN32 */
 
 #ifdef WIN32
 #ifndef ssize_t
@@ -168,9 +197,9 @@ typedef unsigned long long uint64;
 # ifndef ETC_PREFIX
 #   define ETC_PREFIX   "c:/"
 # endif
-#else
+#else /* #ifndef __MINGW32__ */
 typedef DWORD size_t;
-#endif
+#endif /* #ifndef __MINGW32__ */
 
 #else /* !defined(__MINGW32__) && !defined(__CYGWIN32__) */
 
@@ -235,7 +264,7 @@ typedef unsigned __int64 uint64;
 #define	ETC_PREFIX "c:/"
 #endif
 
-#endif
+#endif /* !defined(__MINGW32__) && !defined(__CYGWIN32__) */
 
 // have exceptions
 #ifdef	CCXX_NO_EXCEPTIONS
@@ -258,8 +287,7 @@ typedef unsigned __int64 uint64;
 #define	HAVE_LOCALTIME_R
 #endif
 
-
-#endif
+#endif /* #ifndef CCXX_CONFIG_H_ */
 
 /** EMACS **
  * Local variables:
